@@ -8,7 +8,7 @@
 #ifndef __LIBXMLPP_VALIDATOR_H
 #define __LIBXMLPP_VALIDATOR_H
 
-#ifdef WIN32 //TODO: Why do we do this? murrayc.
+#ifdef _MSC_VER //Ignore warnings about the Visual C++ Bug, where we can not do anything
 #pragma warning (disable : 4786)
 #endif
 
@@ -16,24 +16,19 @@
 #include <libxml++/exceptions/validity_error.h>
 #include <libxml++/exceptions/internal_error.h>
 
-#ifdef WIN32 //TODO: Why do we do this? murrayc.
-#define vsnprintf _vsnprintf
-#endif
-
 extern "C" {
   struct _xmlValidCtxt;
 }
 
 namespace xmlpp {
 
-/** XML parser.
- *
+/** Base class for XML validators.
  */
 class Validator : NonCopyable
 {
 public:
   Validator();
-  virtual ~Validator();
+  ~Validator() override;
 
 protected:
   virtual void initialize_valid();
@@ -42,6 +37,8 @@ protected:
   virtual void on_validity_error(const Glib::ustring& message);
   virtual void on_validity_warning(const Glib::ustring& message);
 
+  //TODO: When we can break ABI/API, remove handleException() and make
+  // handle_exception() protected virtual.
   virtual void handleException(const exception& e);
   virtual void check_for_exception();
   virtual void check_for_validity_messages();
@@ -53,6 +50,10 @@ protected:
   exception* exception_;
   Glib::ustring validate_error_;
   Glib::ustring validate_warning_; //Built gradually - used in an exception at the end of parsing.
+
+private:
+  /// To be called in an exception handler.
+  void handle_exception();
 };
 
 } // namespace xmlpp
